@@ -58,6 +58,7 @@ appropriate hard process.
 The PDG <code>id</code> code for the first incoming particle.
 Allowed codes include 
 <br/><i>2212 = p</i>, <i>-2212 = pbar</i>, 
+<br/><i>2112 = n</i>, <i>-2112 = nbar</i>, 
 <br/><i>211 = pi^+</i>, <i>-211 = pi^-</i>, <i>111 = pi^0</i>,  
 <br/><i>990 = Pomeron</i> (used in diffractive machinery;
 here mainly for debug purposes),
@@ -134,14 +135,40 @@ The name of a Les Houches Event File,
 to be set if <code>Beams:frameType</code> = 4. 
   
 
-<br/><br/><strong>Beams:newLHEFsameInit</strong>  <input type="radio" name="14" value="on"><strong>On</strong>
-<input type="radio" name="14" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><table><tr><td><strong>Beams:LHEFheader  </td><td></td><td> <input type="text" name="14" value="void" size="20"/>  &nbsp;&nbsp;(<code>default = <strong>void</strong></code>)</td></tr></table>
+As some information in a Les Houches Event File init block is only known
+at the end of generation, some programs choose to output this as a
+separate file. If <code>Beams:LHEFheader</code> is given, information up
+till the end of the init block is read from this file, with
+the events themselves read as usual from the file given in
+<code>Beams:LHEF</code>.
+  
+
+<br/><br/><strong>Beams:newLHEFsameInit</strong>  <input type="radio" name="15" value="on"><strong>On</strong>
+<input type="radio" name="15" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Allow to begin reading events from a new LHEF or or a new 
 <code>LHAup</code> instance without a completely new initialization. 
 Only useful when <code>Beams:frameType</code> = 4 or 5.
   
 
+<br/><br/><strong>Beams:readLHEFheaders</strong>  <input type="radio" name="16" value="on" checked="checked"><strong>On</strong>
+<input type="radio" name="16" value="off"><strong>Off</strong>
+ &nbsp;&nbsp;(<code>default = <strong>on</strong></code>)<br/>
+Read in LHEF header blocks and store them in the
+<?php $filepath = $_GET["filepath"];
+echo "<a href='EventInformation.php?filepath=".$filepath."' target='page'>";?>Info</a> class. See also
+<?php $filepath = $_GET["filepath"];
+echo "<a href='LesHouchesAccord.php?filepath=".$filepath."' target='page'>";?>LHAupLHEF</a> for more information.
+  
+
+<p/><code>mode&nbsp; </code><strong> Beams:nSkipLHEFatInit &nbsp;</strong> 
+ (<code>default = <strong>0</strong></code>)<br/>
+Skip the first <i>nSkip</i> events of the input stream 
+(cf. the <code>LHAup::skipEvent(nSkip)</code> method).
+Only used when <code>Beams:frameType</code> = 4 or 5.
+  
+
 <h3>Beam momentum spread</h3>
 
 This framework currently is intended for a modest beam spread, such as
@@ -160,29 +187,29 @@ parametrization, you can write and link your own
 <code><?php $filepath = $_GET["filepath"];
 echo "<a href='BeamShape.php?filepath=".$filepath."' target='page'>";?>BeamShape</a></code> class.
 
-<br/><br/><strong>Beams:allowMomentumSpread</strong>  <input type="radio" name="15" value="on"><strong>On</strong>
-<input type="radio" name="15" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>Beams:allowMomentumSpread</strong>  <input type="radio" name="17" value="on"><strong>On</strong>
+<input type="radio" name="17" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Allow the beam momenta to be smeared around their initialization
 nominal values. 
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaPxA </td><td></td><td> <input type="text" name="16" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaPxA </td><td></td><td> <input type="text" name="18" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the <i>p_x</i> spread of the
 first incoming particle.
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaPyA </td><td></td><td> <input type="text" name="17" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaPyA </td><td></td><td> <input type="text" name="19" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the <i>p_y</i> spread of the
 first incoming particle.
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaPzA </td><td></td><td> <input type="text" name="18" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaPzA </td><td></td><td> <input type="text" name="20" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the <i>p_z</i> spread of the
 first incoming particle.
   
 
-<br/><br/><table><tr><td><strong>Beams:maxDevA </td><td></td><td> <input type="text" name="19" value="5." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:maxDevA </td><td></td><td> <input type="text" name="21" value="5." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The triply Gaussian distribution <i>(p_x, p_y, p_z)</i> is restricted to 
 a maximal total deviation from the nominal values <i>(p_x0, p_y0, p_z0)</i>
 for the first incoming particle, like
@@ -194,22 +221,22 @@ for the first incoming particle, like
 used to pick <i>(p_x, p_y, p_z)</i>.) 
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaPxB </td><td></td><td> <input type="text" name="20" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaPxB </td><td></td><td> <input type="text" name="22" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the <i>p_x</i> spread of the
 second incoming particle.
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaPyB </td><td></td><td> <input type="text" name="21" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaPyB </td><td></td><td> <input type="text" name="23" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the <i>p_y</i> spread of the
 second incoming particle.
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaPzB </td><td></td><td> <input type="text" name="22" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaPzB </td><td></td><td> <input type="text" name="24" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the <i>p_z</i> spread of the
 second incoming particle.
   
 
-<br/><br/><table><tr><td><strong>Beams:maxDevB </td><td></td><td> <input type="text" name="23" value="5." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:maxDevB </td><td></td><td> <input type="text" name="25" value="5." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The triply Gaussian distribution <i>(p_x, p_y, p_z)</i> is restricted to 
 a maximal total deviation from the nominal values <i>(p_x0, p_y0, p_z0)</i>, 
 for the second incoming particle, like
@@ -229,29 +256,29 @@ parametrization, you can write and link your own
 <code><?php $filepath = $_GET["filepath"];
 echo "<a href='BeamShape.php?filepath=".$filepath."' target='page'>";?>BeamShape</a></code> class.
 
-<br/><br/><strong>Beams:allowVertexSpread</strong>  <input type="radio" name="24" value="on"><strong>On</strong>
-<input type="radio" name="24" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>Beams:allowVertexSpread</strong>  <input type="radio" name="26" value="on"><strong>On</strong>
+<input type="radio" name="26" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Allow the interaction vertex of the two colliding beams to be smeared.
 If off, then the vertex is set to be the origin.
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaVertexX </td><td></td><td> <input type="text" name="25" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaVertexX </td><td></td><td> <input type="text" name="27" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the <i>x</i> location of the
 interaction vertex. 
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaVertexY </td><td></td><td> <input type="text" name="26" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaVertexY </td><td></td><td> <input type="text" name="28" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the <i>y</i> location of the
 interaction vertex. 
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaVertexZ </td><td></td><td> <input type="text" name="27" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaVertexZ </td><td></td><td> <input type="text" name="29" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the <i>z</i> location of the
 interaction vertex. 
   
 
-<br/><br/><table><tr><td><strong>Beams:maxDevVertex </td><td></td><td> <input type="text" name="28" value="5." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:maxDevVertex </td><td></td><td> <input type="text" name="30" value="5." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The triply Gaussian distribution of interaction vertex position 
 <i>(x, y, z)</i> is restricted to a maximal total deviation from the 
 origin, like
@@ -262,7 +289,7 @@ x^2/sigma_x^2 + y^2/sigma_y^2 + z^2/sigma_z^2 < maxDevVertex^2
 used to pick <i>(x, y, z)</i>.) 
   
 
-<br/><br/><table><tr><td><strong>Beams:sigmaTime </td><td></td><td> <input type="text" name="29" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:sigmaTime </td><td></td><td> <input type="text" name="31" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The width of a Gaussian distribution of the collision time (in units of
 mm/c). Note that, if the above space parametrization is viewed as the
 effect of two incoming beams along the <i>+-z</i> axis, with each beam
@@ -272,7 +299,7 @@ velocity of the beams, which we expect is close to unity). For flexibility
 we have not enforced any such relation, however. 
   
 
-<br/><br/><table><tr><td><strong>Beams:maxDevTime </td><td></td><td> <input type="text" name="30" value="5." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:maxDevTime </td><td></td><td> <input type="text" name="32" value="5." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5.</strong></code>; <code>minimum = 0.</code>)</td></tr></table>
 The collision time is restricted to be in the range 
 <i>|t| &lt; sigma_t * maxDevTime</i>. 
   
@@ -283,19 +310,19 @@ possible to shift the above distributions to be centered around another
 nominal position. You must have <code>Beams:allowVertexSpread = on</code>
 to use this possibility.
 
-<br/><br/><table><tr><td><strong>Beams:offsetVertexX </td><td></td><td> <input type="text" name="31" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:offsetVertexX </td><td></td><td> <input type="text" name="33" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
 The <i>x</i> location of the interaction vertex is centered at this value. 
   
 
-<br/><br/><table><tr><td><strong>Beams:offsetVertexY </td><td></td><td> <input type="text" name="32" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:offsetVertexY </td><td></td><td> <input type="text" name="34" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
 The <i>y</i> location of the interaction vertex is centered at this value. 
   
 
-<br/><br/><table><tr><td><strong>Beams:offsetVertexZ </td><td></td><td> <input type="text" name="33" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:offsetVertexZ </td><td></td><td> <input type="text" name="35" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
 The <i>z</i> location of the interaction vertex is centered at this value. 
   
 
-<br/><br/><table><tr><td><strong>Beams:offsetTime </td><td></td><td> <input type="text" name="34" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>Beams:offsetTime </td><td></td><td> <input type="text" name="36" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
 The time <i>t</i> of the interaction vertex is centered at this value. 
   
 
@@ -379,109 +406,119 @@ if($_POST["13"] != "void")
 $data = "Beams:LHEF = ".$_POST["13"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["14"] != "off")
+if($_POST["14"] != "void")
 {
-$data = "Beams:newLHEFsameInit = ".$_POST["14"]."\n";
+$data = "Beams:LHEFheader = ".$_POST["14"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["15"] != "off")
 {
-$data = "Beams:allowMomentumSpread = ".$_POST["15"]."\n";
+$data = "Beams:newLHEFsameInit = ".$_POST["15"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["16"] != "0.")
+if($_POST["16"] != "on")
 {
-$data = "Beams:sigmaPxA = ".$_POST["16"]."\n";
+$data = "Beams:readLHEFheaders = ".$_POST["16"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["17"] != "0.")
+if($_POST["17"] != "off")
 {
-$data = "Beams:sigmaPyA = ".$_POST["17"]."\n";
+$data = "Beams:allowMomentumSpread = ".$_POST["17"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["18"] != "0.")
 {
-$data = "Beams:sigmaPzA = ".$_POST["18"]."\n";
+$data = "Beams:sigmaPxA = ".$_POST["18"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["19"] != "5.")
+if($_POST["19"] != "0.")
 {
-$data = "Beams:maxDevA = ".$_POST["19"]."\n";
+$data = "Beams:sigmaPyA = ".$_POST["19"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["20"] != "0.")
 {
-$data = "Beams:sigmaPxB = ".$_POST["20"]."\n";
+$data = "Beams:sigmaPzA = ".$_POST["20"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["21"] != "0.")
+if($_POST["21"] != "5.")
 {
-$data = "Beams:sigmaPyB = ".$_POST["21"]."\n";
+$data = "Beams:maxDevA = ".$_POST["21"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["22"] != "0.")
 {
-$data = "Beams:sigmaPzB = ".$_POST["22"]."\n";
+$data = "Beams:sigmaPxB = ".$_POST["22"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["23"] != "5.")
+if($_POST["23"] != "0.")
 {
-$data = "Beams:maxDevB = ".$_POST["23"]."\n";
+$data = "Beams:sigmaPyB = ".$_POST["23"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["24"] != "off")
+if($_POST["24"] != "0.")
 {
-$data = "Beams:allowVertexSpread = ".$_POST["24"]."\n";
+$data = "Beams:sigmaPzB = ".$_POST["24"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["25"] != "0.")
+if($_POST["25"] != "5.")
 {
-$data = "Beams:sigmaVertexX = ".$_POST["25"]."\n";
+$data = "Beams:maxDevB = ".$_POST["25"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["26"] != "0.")
+if($_POST["26"] != "off")
 {
-$data = "Beams:sigmaVertexY = ".$_POST["26"]."\n";
+$data = "Beams:allowVertexSpread = ".$_POST["26"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["27"] != "0.")
 {
-$data = "Beams:sigmaVertexZ = ".$_POST["27"]."\n";
+$data = "Beams:sigmaVertexX = ".$_POST["27"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["28"] != "5.")
+if($_POST["28"] != "0.")
 {
-$data = "Beams:maxDevVertex = ".$_POST["28"]."\n";
+$data = "Beams:sigmaVertexY = ".$_POST["28"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["29"] != "0.")
 {
-$data = "Beams:sigmaTime = ".$_POST["29"]."\n";
+$data = "Beams:sigmaVertexZ = ".$_POST["29"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["30"] != "5.")
 {
-$data = "Beams:maxDevTime = ".$_POST["30"]."\n";
+$data = "Beams:maxDevVertex = ".$_POST["30"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["31"] != "0.")
 {
-$data = "Beams:offsetVertexX = ".$_POST["31"]."\n";
+$data = "Beams:sigmaTime = ".$_POST["31"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["32"] != "0.")
+if($_POST["32"] != "5.")
 {
-$data = "Beams:offsetVertexY = ".$_POST["32"]."\n";
+$data = "Beams:maxDevTime = ".$_POST["32"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["33"] != "0.")
 {
-$data = "Beams:offsetVertexZ = ".$_POST["33"]."\n";
+$data = "Beams:offsetVertexX = ".$_POST["33"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["34"] != "0.")
 {
-$data = "Beams:offsetTime = ".$_POST["34"]."\n";
+$data = "Beams:offsetVertexY = ".$_POST["34"]."\n";
+fwrite($handle,$data);
+}
+if($_POST["35"] != "0.")
+{
+$data = "Beams:offsetVertexZ = ".$_POST["35"]."\n";
+fwrite($handle,$data);
+}
+if($_POST["36"] != "0.")
+{
+$data = "Beams:offsetTime = ".$_POST["36"]."\n";
 fwrite($handle,$data);
 }
 fclose($handle);
@@ -491,4 +528,4 @@ fclose($handle);
 </body>
 </html>
 
-<!-- Copyright (C) 2012 Torbjorn Sjostrand -->
+<!-- Copyright (C) 2013 Torbjorn Sjostrand -->
