@@ -583,7 +583,7 @@ events, i.e. returned <code>false</code>.
 <code>SlowJet</code> is a simple program for doing jet finding according
 to either of the <i>kT</i>, anti-<i>kT</i>, and Cambridge/Aachen
 algorithms, in a cylindrical coordinate frame. The name is obviously 
-an homage to the <code>FastJet</code> program [<a href="Bibliography.php" target="page">Cac06</a>]. 
+an homage to the <code>FastJet</code> program [<a href="Bibliography.php" target="page">Cac06, Cac12</a>]. 
 That package contains many more algorithms, with many more options,
 and, above all, is <i>much</i> faster. Therefore <code>SlowJet</code>
 is not so much intended for massive processing of data or Monte Carlo
@@ -597,6 +597,18 @@ be used for tricks like distributing a dense grid of pseudoparticles
 to be able to define jet areas, like <code>FastJet</code> can, and also 
 not for events with much pileup or other noise. 
 
+<p/> 
+The recent introduction of <code>fjcore</code>, containing the core
+functionality of <code>FastJet</code> in a very much smaller package,
+has changed the conditions. It now is possible (even encouraged by the 
+authors) to distribute the two <code>fjcore</code> files as part of the
+PYTHIA package. Therefore the <code>SlowJet</code> class doubles as a 
+convenient front end to <code>fjcore</code>, managing the conversion 
+back and forth between PYTHIA and <code>FastJet</code> variables. Some 
+applications may still benefit from using the native codes, but the default 
+now is to let <code>SlowJet</code> call on <code>fjcore</code> for the 
+jet finding.   
+
 <p/> 
 The first step is to decide which particles should be included in the
 analysis, and with what four-momenta. The <code>SlowJet</code> constructor
@@ -670,7 +682,7 @@ The minimal procedure only requires one call per event to do the analysis.
 We will begin by presenting it, and only afterwards some extensions.
 
 <a name="method37"></a>
-<p/><strong>SlowJet::SlowJet(double power, double R, double pTjetMin = 0.,double etaMax = 25., int select = 2, int massSet = 2, SlowJetHook* sjHookPtr = 0, bool useStandardR = true) &nbsp;</strong> <br/>
+<p/><strong>SlowJet::SlowJet(int power, double R, double pTjetMin = 0.,double etaMax = 25., int select = 2, int massSet = 2, SlowJetHook* sjHookPtr = 0, bool useFJcore = true, bool useStandardR = true) &nbsp;</strong> <br/>
 create a <code>SlowJet</code> instance, where 
 <br/><code>argument</code><strong> power </strong>  :  
 tells (half) the power of the transverse-momentum dependence of the 
@@ -713,7 +725,7 @@ assigned the <i>pi+-</i> mass, and
   
 <br/><code>argumentoption </code><strong> 2</strong> : all given their correct masses.  
   
-<<br/><code>argument</code><strong> sjHookPtr </strong> (<code>default = <strong>0</strong></code>) :  
+<br/><code>argument</code><strong> sjHookPtr </strong> (<code>default = <strong>0</strong></code>) :  
 gives the possibility to send in your own selection routine for which
 particles should be part of the analysis; see further below on the
 <code>SlowJetHook</code> class. If this pointer is sent in nonzero, 
@@ -721,8 +733,21 @@ particles should be part of the analysis; see further below on the
 and <code>select</code> only gives the basic selection, to which
 the user can add further requirements.
   
+<br/><code>argument</code><strong> useFJcore </strong> (<code>default = <strong>true</strong></code>) : choice of code used for finding 
+the jets. Does not affect the outcome of the analysis, but only the speed,
+and some more specialized options.
+<br/><code>argumentoption </code><strong> true</strong> : use the <code>fjcore</code> package of 
+<code>FastJet 3.0.5</code>.
+  
+<br/><code>argumentoption </code><strong> false</strong> : use the native <code>SlowJet</code> implementation,
+which gives a slower jet finding, but allows some extra options of
+step-by-step jet joining.
+  
+  
 <br/><code>argument</code><strong> useStandardR </strong> (<code>default = <strong>true</strong></code>) : definition of <i>R</i>
-distance between two jets.
+distance between two jets. This switch is only meaningful for 
+<code>useFJcore = false</code>; within the <code>fjcore</code> package
+the standard option below is always used.
 <br/><code>argumentoption </code><strong> true</strong> : standard, as described above, 
 <i>DeltaR_ij^2 = (y_i - y_j)^2 + (phi_i - phi_j)^2.</i> 
   
@@ -730,7 +755,7 @@ distance between two jets.
 <i>DeltaR_ij^2 = 2 (cosh(y_i - y_j) - cos(phi_i - phi_j))</i>,
 which corresponds to the rim of the "deformed cone" giving a constant
 invariant mass between the two partons considered (for fixed
-masses and transverse momenta).
+masses and transverse momenta). 
   
   
   
@@ -791,34 +816,41 @@ gives the number of particles clustered into the <i>i</i>'th jet,
   
 
 <a name="method45"></a>
+<p/><strong>vector&lt;int&gt; SlowJet::constituents(int i) &nbsp;</strong> <br/>
+gives a list of the indices of the particles that have been
+clustered into the <i>i</i>'th jet,
+  
+
+<a name="method46"></a>
 <p/><strong>int SlowJet::jetAssignment(int i) &nbsp;</strong> <br/>
 gives the index of the jet that the particle <i>i</i> of the event
 record belongs to, or -1 if there is no jet containing particle
 <i>i</i>,
   
 
-<a name="method46"></a>
+<a name="method47"></a>
 <p/><strong>void SlowJet::removeJet(int i) &nbsp;</strong> <br/>
 removes the <i>i</i>'th jet,
   
 
-<a name="method47"></a>
+<a name="method48"></a>
 <p/><strong>void SlowJet::list() &nbsp;</strong> <br/>
-provides a listing of the above information.
+provides a listing of the basic jet information from above.
   
 
 <p/> 
 These are the basic methods. For more sophisticated usage
-it is possible to trace the clustering, one step at a time. If so, the
-<code>setup</code> method should be used to read in the event and find
-the initial smallest distance. Each subsequent <code>doStep</code>
-will then do one cluster joining and find the new smallest distance.
-You can therefore interrogate which clusters will be joined next
-before the joining actually is performed. Alternatively you can take
-several steps in one go, or take steps down to a predetermined number 
-of jets plus remaining clusters. 
+it is possible to trace the clustering, one step at a time. 
+It requires the native jet finding code, <code>useFJcore = false</code>
+in the constructor. If so, the <code>setup</code> method should be used 
+to read in the event and find the initial smallest distance. Each subsequent 
+<code>doStep</code> will then do one cluster joining and find the new 
+smallest distance. You can therefore interrogate which clusters will be 
+joined next before the joining actually is performed. Alternatively you 
+can take several steps in one go, or take steps down to a predetermined 
+number of jets plus remaining clusters. 
 
-<a name="method48"></a>
+<a name="method49"></a>
 <p/><strong>bool SlowJet::setup( const Event& event) &nbsp;</strong> <br/>
 selects the particles to be analyzed, calculates initial distances,
 and finds the initial smallest distance.
@@ -829,35 +861,37 @@ most likely the <code>pythia.event</code> one.
 but currently this is not foreseen ever to happen.
   
 
-<a name="method49"></a>
+<a name="method50"></a>
 <p/><strong>bool SlowJet::doStep() &nbsp;</strong> <br/>
 do the next step of the clustering. This can either be that two 
 clusters are joined to one, or that a cluster is promoted to a jet
 (which is discarded if its <i>pT</i> value is below 
 <code>pTjetMin</code>).
 <br/>The routine will only return <code>false</code> if there are no
-clusters left.
+clusters left, or if <code>useFJcore = true</code>.
   
 
-<a name="method50"></a>
+<a name="method51"></a>
 <p/><strong>bool SlowJet::doNSteps(int nStep) &nbsp;</strong> <br/>
 calls the <code>doStep()</code> method <code>nStep</code> times,
 if possible. Will return <code>false</code> if the list of clusters
 is emptied before then. The stored jet information is still perfectly
-fine; it is only the number of steps that is wrong. 
+fine; it is only the number of steps that is wrong. Will also return 
+<code>false</code> if <code>useFJcore = true</code>.
   
 
-<a name="method51"></a>
+<a name="method52"></a>
 <p/><strong>bool SlowJet::stopAtN(int nStop) &nbsp;</strong> <br/>
 calls the <code>doStep()</code> method until a total of <code>nStop</code>
 jet and cluster objects remain. Will return <code>false</code> if this 
 is not possible, specifically if the number of objects already is smaller 
 than <code>nStop</code> when the method is called. The stored jet and 
 cluster information is still perfectly fine; it only does not have the 
-expected multiplicity.
+expected multiplicity. Will also return <code>false</code> if 
+<code>useFJcore = true</code>.
   
 
-<a name="method52"></a>
+<a name="method53"></a>
 <p/><strong>int SlowJet::sizeAll() &nbsp;</strong> <br/>
 gives the total current number of jets and clusters. The jets are 
 numbered 0 through <code>sizeJet() - 1</code>, while the clusters 
@@ -865,6 +899,8 @@ are numbered <code>sizeJet()</code> through <code>sizeAll() - 1</code>.
 (Internally jets and clusters are represented by two separate arrays,
 but are here presented in one flat range.) Note that the jets are ordered 
 in decreasing <i>pT</i>, while the clusters are not ordered.
+When <code>useFJcore = true</code> there are no intermediate steps, and 
+thus the number of clusters is zero (after jet finding).
   
 
 <p/>
@@ -874,7 +910,7 @@ With this extension, the methods <code>double pT(int i)</code>,
 <code>int multiplicity(int i)</code> can be used as before.
 Furthermore, <code>list()</code> generalizes
 
-<a name="method53"></a>
+<a name="method54"></a>
 <p/><strong>void SlowJet::list(bool listAll = false, ostream& os = cout) &nbsp;</strong> <br/>
 provides a listing of the above information.
 <br/><code>argument</code><strong> listAll </strong>  :  lists both jets and clusters if <code>true</code>,
@@ -885,7 +921,7 @@ else only jets.
 <p/>
 Three further methods can be used to check what will happen next.
 
-<a name="method54"></a>
+<a name="method55"></a>
 <p/><strong>int SlowJet::iNext() &nbsp;</strong> <br/>
   
 <strong>int SlowJet::jNext() &nbsp;</strong> <br/>
@@ -898,7 +934,9 @@ If no clusters remain then <i>(-1, -1, 0.)</i>. Note that
 the cluster numbers are offset as described above, i.e. they begin at
 <code>sizeJet()</code>, which of course easily could be subtracted off.
 Also note that the jet and cluster lists are (moderately) reshuffled 
-in each new step.
+in each new step. When <code>useFJcore = true</code> there are no 
+intermediate steps, and thus these methods do not return meaningul
+information.
   
  
 <p/>
@@ -919,7 +957,7 @@ constructor.
 <p/> 
 The following methods should be defined in your derived class.
 
-<a name="method55"></a>
+<a name="method56"></a>
 <p/><strong>SlowJetHook::SlowJetHook() &nbsp;</strong> <br/>
   
 <strong>virtual SlowJetHook::~SlowJetHook() &nbsp;</strong> <br/>
@@ -927,7 +965,7 @@ the constructor and destructor need not do anything, and if so you
 need not write your own destructor.
   
 
-<a name="method56"></a>
+<a name="method57"></a>
 <p/><strong>virtual bool SlowJetHook::include(int iSel, const Event& event, Vec4& pSel, double& mSel) &nbsp;</strong> <br/>
 is the main method that you will need to write. It will be called 
 once for each final-state particle in an event, subject to the 
