@@ -69,8 +69,8 @@ quantities such as absolute momentum and direction angles.
 A few methods are available to create or copy a four-vector:
 
 <a name="method1"></a>
-<p/><strong>Vec4::Vec4() &nbsp;</strong> <br/>
-creates a four-vector with all components set to 0.
+<p/><strong>Vec4::Vec4(double x = 0., double y = 0., double z = 0., double t = 0.) &nbsp;</strong> <br/>
+creates a four-vector, by default with all components set to 0.
   
 
 <a name="method2"></a>
@@ -190,13 +190,20 @@ the angle in the <i>xz</i> plane, in the range <i>-pi</i> through
 <strong>double Vec4::pNeg() &nbsp;</strong> <br/>
 the combinations <i>E+-p_z</i>.  
 
+<a name="method18"></a>
+<p/><strong>double Vec4::rap() &nbsp;</strong> <br/>
+  
+<strong>double Vec4::eta() &nbsp;</strong> <br/>
+true rapidity <i>y</i> and pseudorapidity <i>eta</i>.
+  
+
 <h3>Friend methods for output</h3>
 
 There are also some <code>friend</code> methods that take one, two 
 or three four-vectors as argument. Several of them only use the
 three-vector part of the four-vector.
 
-<a name="method18"></a>
+<a name="method19"></a>
 <p/><strong>friend ostream& operator&lt;&lt;(ostream&, const Vec4& v) &nbsp;</strong> <br/>
 writes out the values of the four components of a <code>Vec4</code> and,
 within brackets, a fifth component being the invariant length of the 
@@ -204,24 +211,24 @@ four-vector, as provided by <code>mCalc()</code> above, and it all
 ended with a newline.
   
 
-<a name="method19"></a>
+<a name="method20"></a>
 <p/><strong>friend double m(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
   
 <strong>friend double m2(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
 the (squared) invariant mass.
   
 
-<a name="method20"></a>
+<a name="method21"></a>
 <p/><strong>friend double dot3(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
 the three-product.
   
 
-<a name="method21"></a>
+<a name="method22"></a>
 <p/><strong>friend double cross3(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
 the cross-product.
   
 
-<a name="method22"></a>
+<a name="method23"></a>
 <p/><strong>friend double theta(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
   
 <strong>friend double costheta(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
@@ -229,7 +236,7 @@ the (cosine) of the opening angle between the vectors,
 in the range 0 through <i>pi</i>.
   
 
-<a name="method23"></a>
+<a name="method24"></a>
 <p/><strong>friend double phi(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
   
 <strong>friend double cosphi(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
@@ -237,7 +244,7 @@ the (cosine) of the azimuthal angle between the vectors around the
 <i>z</i> axis, in the range 0 through <i>pi</i>.
   
 
-<a name="method24"></a>
+<a name="method25"></a>
 <p/><strong>friend double phi(const Vec4& v1, const Vec4& v2, const Vec4& v3) &nbsp;</strong> <br/>
   
 <strong>friend double cosphi(const Vec4& v1, const Vec4& v2, const Vec4& v3) &nbsp;</strong> <br/>
@@ -245,60 +252,69 @@ the (cosine) of the azimuthal angle between the first two vectors
 around the direction of the third, in the range 0 through <i>pi</i>.
   
 
+<a name="method26"></a>
+<p/><strong>friend double RRapPhi(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
+  
+<strong>friend double REtaPhi(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
+the <i>R</i> distance measure, in <i>(y, phi)</i> or 
+<i>(eta, phi)</i> cylindrical coordinates, i.e. 
+<i>R^2 = (y_1 - y_2)^2 + (phi_1 - phi_2)^2</i> and equivalent. 
+  
+
 <h3>Operations with four-vectors</h3>
 
 Of course one should be able to add, subtract and scale four-vectors, 
 and more:
 
-<a name="method25"></a>
+<a name="method27"></a>
 <p/><strong>Vec4 Vec4::operator-() &nbsp;</strong> <br/>
 return a vector with flipped sign for all components, while leaving
 the original vector unchanged.
   
 
-<a name="method26"></a>
+<a name="method28"></a>
 <p/><strong>Vec4& Vec4::operator+=(const Vec4& v) &nbsp;</strong> <br/>
 add a four-vector to an existing one.
   
 
-<a name="method27"></a>
+<a name="method29"></a>
 <p/><strong>Vec4& Vec4::operator-=(const Vec4& v) &nbsp;</strong> <br/>
 subtract a four-vector from an existing one.
   
 
-<a name="method28"></a>
+<a name="method30"></a>
 <p/><strong>Vec4& Vec4::operator*=(double f) &nbsp;</strong> <br/>
 multiply all four-vector components by a real number. 
   
 
-<a name="method29"></a>
+<a name="method31"></a>
 <p/><strong>Vec4& Vec4::operator/=(double f) &nbsp;</strong> <br/>
 divide all four-vector components by a real number. 
   
 
-<a name="method30"></a>
+<a name="method32"></a>
 <p/><strong>friend Vec4 operator+(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
 add two four-vectors.
   
 
-<a name="method31"></a>
+<a name="method33"></a>
 <p/><strong>friend Vec4 operator-(const Vec4& v1, const Vec4& v2) &nbsp;</strong> <br/>
 subtract two four-vectors.
   
 
-<a name="method32"></a>
+<a name="method34"></a>
 <p/><strong>friend Vec4 operator*(double f, const Vec4& v) &nbsp;</strong> <br/>
   
 <strong>friend Vec4 operator*(const Vec4& v, double f) &nbsp;</strong> <br/>
 multiply a four-vector by a real number.
   
 
-<a name="method33"></a>
+<a name="method35"></a>
 <p/><strong>friend Vec4 operator/(const Vec4& v, double f) &nbsp;</strong> <br/>
 divide a four-vector by a real number.
   
 
-<a name="method34"></a>
+<a name="method36"></a>
 <p/><strong>friend double operator*(const Vec4& v1, const Vec4 v2) &nbsp;</strong> <br/>
 four-vector product.
   
@@ -306,24 +322,24 @@ four-vector product.
 <p/>
 There are also a few related operations that are normal member methods:
 
-<a name="method35"></a>
+<a name="method37"></a>
 <p/><strong>void Vec4::rescale3(double f) &nbsp;</strong> <br/>
 multiply the three-vector components by <i>f</i>, but keep the 
 fourth component unchanged.
   
 
-<a name="method36"></a>
+<a name="method38"></a>
 <p/><strong>void Vec4::rescale4(double f) &nbsp;</strong> <br/>
 multiply all four-vector components by <i>f</i>.
   
 
-<a name="method37"></a>
+<a name="method39"></a>
 <p/><strong>void Vec4::flip3() &nbsp;</strong> <br/>
 flip the sign of the three-vector components, but keep the 
 fourth component unchanged.
   
 
-<a name="method38"></a>
+<a name="method40"></a>
 <p/><strong>void Vec4::flip4() &nbsp;</strong> <br/>
 flip the sign of all four-vector components.
   
@@ -335,62 +351,62 @@ four-vector is affected the operation may be performed directly on it.
 However, in case many particles are affected, the helper class
 <code>RotBstMatrix</code> can be used to speed up operations.
 
-<a name="method39"></a>
+<a name="method41"></a>
 <p/><strong>void Vec4::rot(double theta, double phi) &nbsp;</strong> <br/>
 rotate the three-momentum with the polar angle <i>theta</i>
 and the azimuthal angle <i>phi</i>.
   
 
-<a name="method40"></a>
+<a name="method42"></a>
 <p/><strong>void Vec4::rotaxis(double phi, double nx, double ny, double nz) &nbsp;</strong> <br/>
 rotate the three-momentum with the azimuthal angle <i>phi</i>
 around the direction defined by the <i>(n_x, n_y, n_z)</i>
 three-vector.
   
 
-<a name="method41"></a>
+<a name="method43"></a>
 <p/><strong>void Vec4::rotaxis(double phi, Vec4& n) &nbsp;</strong> <br/>
 rotate the three-momentum with the azimuthal angle <i>phi</i>
 around the direction defined by the three-vector part of <i>n</i>. 
   
 
-<a name="method42"></a>
+<a name="method44"></a>
 <p/><strong>void Vec4::bst(double betaX, double betaY, double betaZ) &nbsp;</strong> <br/>
 boost the four-momentum by <i>beta = (beta_x, beta_y, beta_z)</i>.
   
 
-<a name="method43"></a>
+<a name="method45"></a>
 <p/><strong>void Vec4::bst(double betaX, double betaY, double betaZ,double gamma) &nbsp;</strong> <br/>
 boost the four-momentum by <i>beta = (beta_x, beta_y, beta_z)</i>,
 where the <i>gamma = 1/sqrt(1 - beta^2)</i> is also input to allow
 better precision when <i>beta</i> is close to unity. 
   
 
-<a name="method44"></a>
+<a name="method46"></a>
 <p/><strong>void Vec4::bst(const Vec4& p) &nbsp;</strong> <br/>
 boost the four-momentum by <i>beta = (p_x/E, p_y/E, p_z/E)</i>.
   
 
-<a name="method45"></a>
+<a name="method47"></a>
 <p/><strong>void Vec4::bst(const Vec4& p, double m) &nbsp;</strong> <br/>
 boost the four-momentum by <i>beta = (p_x/E, p_y/E, p_z/E)</i>,
 where the <i>gamma = E/m</i> is also calculated from input to allow
 better precision when <i>beta</i> is close to unity. 
   
 
-<a name="method46"></a>
+<a name="method48"></a>
 <p/><strong>void Vec4::bstback(const Vec4& p) &nbsp;</strong> <br/>
 boost the four-momentum by <i>beta = (-p_x/E, -p_y/E, -p_z/E)</i>.
   
 
-<a name="method47"></a>
+<a name="method49"></a>
 <p/><strong>void Vec4::bstback(const Vec4& p, double m) &nbsp;</strong> <br/>
 boost the four-momentum by <i>beta = (-p_x/E, -p_y/E, -p_z/E)</i>,
 where the <i>gamma = E/m</i> is also calculated from input to allow
 better precision when <i>beta</i> is close to unity. 
   
 
-<a name="method48"></a>
+<a name="method50"></a>
 <p/><strong>void Vec4::rotbst(const RotBstMatrix& M) &nbsp;</strong> <br/>
 perform a combined rotation and boost; see below for a description
 of the <code>RotBstMatrix</code>.
@@ -407,82 +423,82 @@ The order in which you do these calls must agree with the imagined
 order in which the rotations/boosts should be applied to a 
 four-momentum, since in general the operations do not commute.
 
-<a name="method49"></a>
+<a name="method51"></a>
 <p/><strong>RotBstMatrix::RotBstMatrix() &nbsp;</strong> <br/>
 creates a diagonal unit matrix, i.e. one that leaves a four-vector
 unchanged.
   
 
-<a name="method50"></a>
+<a name="method52"></a>
 <p/><strong>RotBstMatrix::RotBstMatrix(const RotBstMatrix& Min) &nbsp;</strong> <br/>
 creates a copy of the input matrix.
   
 
-<a name="method51"></a>
+<a name="method53"></a>
 <p/><strong>RotBstMatrix& RotBstMatrix::operator=(const RotBstMatrix4& Min) &nbsp;</strong> <br/>
 copies the input matrix.
   
 
-<a name="method52"></a>
+<a name="method54"></a>
 <p/><strong>void RotBstMatrix::rot(double theta = 0., double phi = 0.) &nbsp;</strong> <br/>
 rotate by this polar and azimuthal angle.
   
 
-<a name="method53"></a>
+<a name="method55"></a>
 <p/><strong>void RotBstMatrix::rot(const Vec4& p) &nbsp;</strong> <br/>
 rotate so that a vector originally along the <i>+z</i> axis becomes 
 parallel with <i>p</i>. More specifically, rotate by <i>-phi</i>, 
 <i>theta</i> and <i>phi</i>, with angles defined by <i>p</i>.
   
 
-<a name="method54"></a>
+<a name="method56"></a>
 <p/><strong>void RotBstMatrix::bst(double betaX = 0., double betaY = 0., double betaZ = 0.) &nbsp;</strong> <br/>
 boost by this <i>beta</i> vector.
   
 
-<a name="method55"></a>
+<a name="method57"></a>
 <p/><strong>void RotBstMatrix::bst(const Vec4&) &nbsp;</strong> <br/>
   
 <strong>void RotBstMatrix::bstback(const Vec4&) &nbsp;</strong> <br/>
 boost with a <i>beta = p/E</i> or <i>beta = -p/E</i>, respectively.
   
 
-<a name="method56"></a>
+<a name="method58"></a>
 <p/><strong>void RotBstMatrix::bst(const Vec4& p1, const Vec4& p2) &nbsp;</strong> <br/>
 boost so that <i>p_1</i> is transformed to <i>p_2</i>. It is assumed 
 that the two vectors obey <i>p_1^2 = p_2^2</i>.
   
 
-<a name="method57"></a>
+<a name="method59"></a>
 <p/><strong>void RotBstMatrix::toCMframe(const Vec4& p1, const Vec4& p2) &nbsp;</strong> <br/>
 boost and rotate to the rest frame of <i>p_1</i> and <i>p_2</i>, 
 with <i>p_1</i> along the <i>+z</i> axis.
   
 
-<a name="method58"></a>
+<a name="method60"></a>
 <p/><strong>void RotBstMatrix::fromCMframe(const Vec4& p1, const Vec4& p2) &nbsp;</strong> <br/>
 rotate and boost from the rest frame of <i>p_1</i> and <i>p_2</i>, 
 with <i>p_1</i> along the <i>+z</i> axis, to the actual frame of 
 <i>p_1</i> and <i>p_2</i>, i.e. the inverse of the above.
   
 
-<a name="method59"></a>
+<a name="method61"></a>
 <p/><strong>void RotBstMatrix::rotbst(const RotBstMatrix& Min); &nbsp;</strong> <br/>
 combine the current matrix with another one.
   
 
-<a name="method60"></a>
+<a name="method62"></a>
 <p/><strong>void RotBstMatrix::invert() &nbsp;</strong> <br/>
 invert the matrix, which corresponds to an opposite sequence and sign 
 of rotations and boosts.
   
 
-<a name="method61"></a>
+<a name="method63"></a>
 <p/><strong>void RotBstMatrix::reset() &nbsp;</strong> <br/>
 reset to no rotation/boost; i.e. the default at creation.
   
 
-<a name="method62"></a>
+<a name="method64"></a>
 <p/><strong>double RotBstMatrix::deviation() &nbsp;</strong> <br/>
 crude estimate how much a matrix deviates from the unit matrix:
 the sum of the absolute values of all non-diagonal matrix elements 
@@ -490,7 +506,7 @@ plus the sum of the absolute deviation of the diagonal matrix
 elements from unity.
   
 
-<a name="method63"></a>
+<a name="method65"></a>
 <p/><strong>friend ostream& operator&lt;&lt;(ostream&, const RotBstMatrix& M) &nbsp;</strong> <br/>
 writes out the values of the sixteen components of a 
 <code>RotBstMatrix</code>, on four consecutive lines and
@@ -500,4 +516,4 @@ ended with a newline.
 </body>
 </html>
 
-<!-- Copyright (C) 2012 Torbjorn Sjostrand -->
+<!-- Copyright (C) 2013 Torbjorn Sjostrand -->
