@@ -35,32 +35,44 @@ jet finders</a>, <code>ClusterJet</code> for <i>e^+e^-</i> events
 and <code>SlowJet</code> and <code>CellJet</code>for hadron collider ones. 
 Especially the latter is not so well matched to the standards of its field, 
 however. (But it is closely related to the anti-<i>kT</i> algorithm,
-so is also not completely disconnected [<a href="Bibliography.php" target="page">Cac08</a>].)  
+so is also not completely disconnected [<a href="Bibliography.php" target="page">Cac08</a>].) 
+
+<p/> 
 <code>SlowJet</code> can do jet finding according to the current-day 
-<i>kT</i>, Cambridge/Aachen and anti-<i>kT</i> algorithms but,
-as the name indicates, is is rather slow, especially when compared with 
-the <code>FastJet</code> alternative.
+<i>kT</i>, Cambridge/Aachen and anti-<i>kT</i> algorithms.
+It can be run in two modes. The original one is a native implementation
+which, as the name indicates, is rather slow. However, with the release
+of the <code>fjcore</code> code from <code>FastJet</code>
+[<a href="Bibliography.php" target="page">Cac06, Cac12</a>], the default mode has become to use the
+<code>fjcore</code> methods. This is transparent to the user.
 
 <h3>FastJet</h3>
 
-For realistic jet studies the <code>FastJet</code> package
-[<a href="Bibliography.php" target="page">Cac06</a>] has become a standard. Several different
-jet options are available, such as <i>kT</i>,
-Cambridge/Aachen, anti-<i>kT</i> and SISCone.
+<code>SlowJet</code> does not exhaust all the posssibilities of the 
+<code>fjcore</code> code, so users are welcome to extend on the existing
+functionality by a direct usage of the <code>fjcore</code> methods.
 
 <p/>
-Linking to <code>FastJet</code> is foreseen in the configure 
-file in the <code>examples</code> subdirectory, and the 
+Missing from <code>fjcore</code> is a number of aspects, such as 
+jet areas functionality, background estimation, access to other algorithms 
+via plugins, interface to CGAL and tools such as filters and taggers.
+Therefore, for more sophisticated jet studies the complete 
+<code>FastJet</code> package needs to be linked. This is foreseen in the 
+configure file in the <code>examples</code> subdirectory, and the 
 <code>main71.cc</code> and <code>main72.cc</code> programs contain
-examples how it can be used with <code>Pythia</code> events.
+examples how it can be used with <code>Pythia</code> events. (Even if 
+these examples do not go beyond the functionality that 
+<code>SlowJet</code> can offer.)
 
 <p/>
-The latter program makes use of the <code>include/FastJet3.h</code>
+The latter program makes use of the <code>include/Pythia8/FastJet3.h</code>
 header file, contributed by Gavin Salam. This allows simple input 
 of a <code>Pythia</code> particle into a <code>FastJet</code> one, 
 either retaining only the four-momentum or the full particle information. 
 Thereby more sophisticated selectors become possible at the 
-<code>FastJet</code> level. 
+<code>FastJet</code> level. This code could be duplicated, with trivial
+modifications, to augment the <code>fjcore</code> package functionality 
+in an identical manner, should the need arise. 
 
 </body>
 </html>
