@@ -524,7 +524,22 @@ the decay chain has already been set, however (e.g. <i>H -> WW/ZZ</i>
 or <i>t -> b W</i>), then decay is still isotropic.
 
 <p/>
-There is only one parameter that can be used to modify the setting
+There is one setting available for event input.
+
+<br/><br/><table><tr><td><strong>LesHouches:setLifetime  </td><td>  &nbsp;&nbsp;(<code>default = <strong>1</strong></code>; <code>minimum = 0</code>; <code>maximum = 2</code>)</td></tr></table>
+handling of the decay time information stored in <code>VTIMUP</code>
+when the Les Houches event record is stored into the PYTHIA 
+<code>process</code> one. The reason is that some matrix-element 
+generators (like POWHEG) do not set decay times, so that it is up to 
+PYTHIA to make that selection. This is particularly important for 
+the <ei>tau</ei> lepton. 
+<br/>
+<input type="radio" name="1" value="0"><strong>0 </strong>:  all decay times are taken from the Les Houches input. <br/>
+<input type="radio" name="1" value="1" checked="checked"><strong>1 </strong>:  the decay time of <ei>tau</ei> leptons is generated like for internal PYTHIA <ei>tau</ei>s, whereas all other decay times  are taken from the Les Houches input. <br/>
+<input type="radio" name="1" value="2"><strong>2 </strong>:  all decay times are generated by PYTHIA, thus completely disregarding the Les Houches values. This option could  go wrong in BSM scenarios with long-lived particles, if PYTHIA  has not been provided with the information to select those lifetimes  correctly.  <br/>
+
+<p/>
+There is also one parameter that can be used to modify the setting
 of event information, if implemented in the derived class. It is 
 prompted by an unforeseen choice made in some programs (like CalcHEP)
 of storing the nominal mass of a particle species rather than the
@@ -532,7 +547,7 @@ mass of the current member of that species. This is likely to
 induce energy-momentum nonconservation when the event is further 
 processed.
 
-<br/><br/><table><tr><td><strong>LesHouches:mRecalculate </td><td></td><td> <input type="text" name="1" value="-1." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>-1.</strong></code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>LesHouches:mRecalculate </td><td></td><td> <input type="text" name="2" value="-1." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>-1.</strong></code>)</td></tr></table>
 Does not have any effect by default, or more generally when it is negative.
 If it is positive then all particles with an input mass above this
 value will have the mass recalculated and reset from the four-momentum,  
@@ -781,13 +796,8 @@ convenient in the early days of PYTHIA 8 evolution, when this program
 did not yet contain hard-process generation, and the LHEF standard 
 did not yet exist. Nowadays it is more of a bother, since a full
 cross-platform support leads to many possible combinations. Therefore
-the support has been reduced in the current version. Only the 
-<code>main91.cc</code> example remains as an illustration, where the
-previously separate interface code 
-(<code>include/Pythia6Interface.h</code>) has been inserted in the 
-beginning. You also need to modify the <code>examples/Makefile</code> 
-to link <code>main91.cc</code> properly also to a PYTHIA 6.4 library
-version, see commented-out section for ideas how to to this.
+this support has been removed, but can still be recuperated from 
+previous code versions, in a reduced form up to version 8.176.
 
 <h3>Methods for LHEF output</h3>
 
@@ -902,9 +912,14 @@ if($_POST["saved"] == 1)
 $filepath = $_POST["filepath"];
 $handle = fopen($filepath, 'a');
 
-if($_POST["1"] != "-1.")
+if($_POST["1"] != "1")
 {
-$data = "LesHouches:mRecalculate = ".$_POST["1"]."\n";
+$data = "LesHouches:setLifetime = ".$_POST["1"]."\n";
+fwrite($handle,$data);
+}
+if($_POST["2"] != "-1.")
+{
+$data = "LesHouches:mRecalculate = ".$_POST["2"]."\n";
 fwrite($handle,$data);
 }
 fclose($handle);
