@@ -149,6 +149,17 @@ subsequent to the hard process itself; on/off = true/false. In addition
 <code>PartonLevel:FSR</code> must be on for these emissions to occur.
   
 
+<br/><br/><strong>PartonLevel:earlyResDec</strong>  <input type="radio" name="9" value="on"><strong>On</strong>
+<input type="radio" name="9" value="off" checked="checked"><strong>Off</strong>
+ &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
+If on then do resonance decays early, before beam handling including
+colour reconnection. If off then decays are done afterwards, and so 
+are unaffected by colour reconnection. The early-decay option is still 
+primitive, for some first studies. Eventually the choice should be
+made individually for each resonance based on lifetime (and the 
+environment).
+  
+
 <p/>
 Switching off all the above MPI/ISR/FSR switches is <b>not</b> equivalent 
 to setting <code>PartonLevel:all = off</code>. In the former case a 
@@ -160,8 +171,8 @@ In the latter case <b>no</b> operations at all are carried out on the
 parton level, and therefore it is also not possible to go on to the 
 hadron level.
 
-<br/><br/><strong>PartonLevel:Remnants</strong>  <input type="radio" name="9" value="on" checked="checked"><strong>On</strong>
-<input type="radio" name="9" value="off"><strong>Off</strong>
+<br/><br/><strong>PartonLevel:Remnants</strong>  <input type="radio" name="10" value="on" checked="checked"><strong>On</strong>
+<input type="radio" name="10" value="off"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>on</strong></code>)<br/>
 Master switch for addition of beam remnants; on/off = true/false.  
 Only intended for very special applications, and cannot be used to 
@@ -190,8 +201,8 @@ the string between the two, so that the topology can be reduced back
 to two separate one-junction systems, while still preserving the
 expected particle flow in the junction-junction string region(s).
 
-<br/><br/><strong>HadronLevel:all</strong>  <input type="radio" name="10" value="on" checked="checked"><strong>On</strong>
-<input type="radio" name="10" value="off"><strong>Off</strong>
+<br/><br/><strong>HadronLevel:all</strong>  <input type="radio" name="11" value="on" checked="checked"><strong>On</strong>
+<input type="radio" name="11" value="off"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>on</strong></code>)<br/>
 If off then stop the generation after the hard process and 
 parton-level activity has been generated, but before the 
@@ -202,24 +213,24 @@ hadron-level steps.
 For <code>HadronLevel:all = on</code> some parts of the event generation 
 on this level may be switched off individually: 
 
-<br/><br/><strong>HadronLevel:Hadronize</strong>  <input type="radio" name="11" value="on" checked="checked"><strong>On</strong>
-<input type="radio" name="11" value="off"><strong>Off</strong>
+<br/><br/><strong>HadronLevel:Hadronize</strong>  <input type="radio" name="12" value="on" checked="checked"><strong>On</strong>
+<input type="radio" name="12" value="off"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>on</strong></code>)<br/>
 Master switch for hadronization; on/off = true/false.
 Further options are found <?php $filepath = $_GET["filepath"];
 echo "<a href='Fragmentation.php?filepath=".$filepath."' target='page'>";?>here</a>.
   
 
-<br/><br/><strong>HadronLevel:Decay</strong>  <input type="radio" name="12" value="on" checked="checked"><strong>On</strong>
-<input type="radio" name="12" value="off"><strong>Off</strong>
+<br/><br/><strong>HadronLevel:Decay</strong>  <input type="radio" name="13" value="on" checked="checked"><strong>On</strong>
+<input type="radio" name="13" value="off"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>on</strong></code>)<br/>
 Master switch for decays; on/off = true/false.
 Further options are found <?php $filepath = $_GET["filepath"];
 echo "<a href='ParticleDecays.php?filepath=".$filepath."' target='page'>";?>here</a>.
   
 
-<br/><br/><strong>HadronLevel:BoseEinstein</strong>  <input type="radio" name="13" value="on"><strong>On</strong>
-<input type="radio" name="13" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>HadronLevel:BoseEinstein</strong>  <input type="radio" name="14" value="on"><strong>On</strong>
+<input type="radio" name="14" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Master switch for the simulation of Bose-Einstein effects; 
 on/off = true/false. Further options are found 
@@ -229,8 +240,8 @@ echo "<a href='BoseEinsteinEffects.php?filepath=".$filepath."' target='page'>";?
 
 <h3>Printing</h3>
 
-<br/><br/><strong>Print:quiet</strong>  <input type="radio" name="14" value="on"><strong>On</strong>
-<input type="radio" name="14" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>Print:quiet</strong>  <input type="radio" name="15" value="on"><strong>On</strong>
+<input type="radio" name="15" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Can be set on to avoid the printing during program execution, to the 
 largest extent possible. This flag acts by setting the relevant values 
@@ -309,34 +320,39 @@ if($_POST["8"] != "on")
 $data = "PartonLevel:FSRinResonances = ".$_POST["8"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["9"] != "on")
+if($_POST["9"] != "off")
 {
-$data = "PartonLevel:Remnants = ".$_POST["9"]."\n";
+$data = "PartonLevel:earlyResDec = ".$_POST["9"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["10"] != "on")
 {
-$data = "HadronLevel:all = ".$_POST["10"]."\n";
+$data = "PartonLevel:Remnants = ".$_POST["10"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["11"] != "on")
 {
-$data = "HadronLevel:Hadronize = ".$_POST["11"]."\n";
+$data = "HadronLevel:all = ".$_POST["11"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["12"] != "on")
 {
-$data = "HadronLevel:Decay = ".$_POST["12"]."\n";
+$data = "HadronLevel:Hadronize = ".$_POST["12"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["13"] != "off")
+if($_POST["13"] != "on")
 {
-$data = "HadronLevel:BoseEinstein = ".$_POST["13"]."\n";
+$data = "HadronLevel:Decay = ".$_POST["13"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["14"] != "off")
 {
-$data = "Print:quiet = ".$_POST["14"]."\n";
+$data = "HadronLevel:BoseEinstein = ".$_POST["14"]."\n";
+fwrite($handle,$data);
+}
+if($_POST["15"] != "off")
+{
+$data = "Print:quiet = ".$_POST["15"]."\n";
 fwrite($handle,$data);
 }
 fclose($handle);
