@@ -56,7 +56,7 @@ echo "<a href='BeamRemnants.php?filepath=".$filepath."' target='page'>";?>beam r
 
 The maximum <i>pT</i> to be allowed for multiparton interactions is
 related to the nature of the hard process itself. It involves a
-delicate balance between not doublecounting and not leaving any
+delicate balance between not double-counting and not leaving any
 gaps in the coverage. The best procedure may depend on information 
 only the user has: how the events were generated and mixed (e.g. with 
 Les Houches Accord external input), and how they are intended to be 
@@ -66,9 +66,14 @@ behaviour.
 Way in which the maximum scale for multiparton interactions is set
 to match the scale of the hard process itself.
 <br/>
-<input type="radio" name="1" value="0" checked="checked"><strong>0 </strong>: <b>(i)</b> if the final state of the hard process  (not counting subsequent resonance decays) contains only quarks  (<ei>u, d, s, c ,b</ei>), gluons and photons then <ei>pT_max</ei>  is chosen to be the factorization scale for internal processes  and the <code>scale</code> value for Les Houches input;  <b>(ii)</b> if not, interactions are allowed to go all the way up  to the kinematical limit.  The reasoning is that the former kind of processes are generated by the multiparton-interactions machinery and so would doublecount hard processes if allowed to overlap the same <ei>pT</ei> range,  while no such danger exists in the latter case. <br/>
-<input type="radio" name="1" value="1"><strong>1 </strong>: always use the factorization scale for an internal process and the <code>scale</code> value for Les Houches input,  i.e. the lower value. This should avoid doublecounting, but may leave out some interactions that ought to have been simulated. <br/>
-<input type="radio" name="1" value="2"><strong>2 </strong>: always allow multiparton interactions up to the  kinematical limit. This will simulate all possible event topologies,  but may lead to doublecounting. <br/>
+<input type="radio" name="1" value="0" checked="checked"><strong>0 </strong>: <b>(i)</b> if the final state of the hard process  (not counting subsequent resonance decays) contains only quarks  (<ei>u, d, s, c, b</ei>), gluons and photons then <ei>pT_max</ei>  is chosen to be the factorization scale for internal processes  and the <code>scale</code> value for Les Houches input;  <b>(ii)</b> if not, interactions are allowed to go all the way up  to the kinematical limit.  The reasoning is that the former kind of processes are generated by the multiparton-interactions machinery and so would double-count hard processes if allowed to overlap the same <ei>pT</ei> range,  while no such danger exists in the latter case. <br/>
+<input type="radio" name="1" value="1"><strong>1 </strong>: always use the factorization scale for an internal process and the <code>scale</code> value for Les Houches input,  i.e. the lower value. This should avoid double-counting, but may leave out some interactions that ought to have been simulated. <br/>
+<input type="radio" name="1" value="2"><strong>2 </strong>: always allow multiparton interactions up to the  kinematical limit. This will simulate all possible event topologies,  but may lead to double-counting. <br/>
+<br/><b>Note:</b> If a "second hard" process is present, the two 
+are analyzed separately for the default 0 option. It is enough that 
+one of them only consists of quarks, gluons and photons to restrict
+the <ei>pT</ei> range. The maximum for MPI is then set by the hard
+interaction with lowest scale.
 
 <h4>Cross-section parameters</h4>
 
@@ -119,7 +124,7 @@ The processes used to generate multiparton interactions form a subset
 of the standard library of hard processes. The input is slightly
 different from the standard hard-process machinery, however, 
 since incoming flavours, the <i>alpha_strong</i> value and most
-of the kinematics are aready fixed when the process is called.
+of the kinematics are already fixed when the process is called.
 It is possible to regulate the set of processes that are included in the
 multiparton-interactions framework.
 
@@ -268,6 +273,28 @@ Gaussian width. When <i>a1 = 0.</i>, this reduces back to the single
 Gaussian case.
   
 
+<br/><br/><table><tr><td><strong>MultipartonInteractions:bSelScale  </td><td>  &nbsp;&nbsp;(<code>default = <strong>1</strong></code>; <code>minimum = 1</code>; <code>maximum = 3</code>)</td></tr></table>
+The selection of impact parameter is related to the scale of the
+hard process: the harder this scale is, the more central the collision.
+In practice this centrality saturates quickly, however, and beyond 
+a scale of roughly 20 GeV very little changes. (The relevant 
+quantity is that the QCD jet cross section above the scale should be
+a tiny fraction of the total cross section.) In <ei>2 -> 1</ei> and
+<ei>2 -> 2</ei> processes traditional scale choices work fine, but 
+ambiguities arise for higher multiplicities, in particular when the
+scale is used for matching between the multiparton matrix elements 
+and parton showers. Then the event scale may 
+be chosen as that of a very low-<ei>pT</ei> parton, i.e. suggesting a
+peripheral collision, while the much harder other partons instead 
+would favour a central collision. Therefore the default here is to  
+override whatever scale value have been read in from an LHEF, say.
+Notice that the scale used here is decoupled from the maximum scale 
+for MPIs (<code>MultipartonInteractions:pTmaxMatch</code>).
+<br/>
+<input type="radio" name="17" value="1" checked="checked"><strong>1 </strong>:  Use the mass for a <ei>2 -> 1</ei> process.  For <ei>2 -> n, n > 1</ei> processes order the particles in  falling <ei>mmT = m + mT</ei> and then let the scale be  <ei>(mmT_1 + mmT_2)/2 + mmT_3/3 + mmT_4/4 + ... + mmT_n/n</ei>. This is constructed always to be above <ei>m1</ei>, and to assign  decreasing importance to softer particles that are less likely to  be associated with the hard process.<br/>
+<input type="radio" name="17" value="2"><strong>2 </strong>: Use the <code>scale</code> parameter of the event.  <br/>
+<input type="radio" name="17" value="3"><strong>3 </strong>: use the same scale as chosen by the rules for <code>MultipartonInteractions:pTmaxMatch</code>.<br/>
+
 <h4>Rescattering</h4>
  
 It is possible that a parton may rescatter, i.e. undergo a further
@@ -276,12 +303,12 @@ kind of physics has only recently become fully operational
 [<a href="Bibliography.php" target="page">Cor09</a>], and is therefore not yet so well explored. 
 
 <p/>
-The rescatting framework has ties with other parts of the program,
+The rescattering framework has ties with other parts of the program,
 notably with the <?php $filepath = $_GET["filepath"];
 echo "<a href='BeamRemnants.php?filepath=".$filepath."' target='page'>";?>beam remnants</a>.
 
-<br/><br/><strong>MultipartonInteractions:allowRescatter</strong>  <input type="radio" name="17" value="on"><strong>On</strong>
-<input type="radio" name="17" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>MultipartonInteractions:allowRescatter</strong>  <input type="radio" name="18" value="on"><strong>On</strong>
+<input type="radio" name="18" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Switch to allow rescattering of partons; on/off = true/false.<br/>
 <b>Note:</b> the rescattering framework has not yet been implemented
@@ -291,8 +318,8 @@ and can therefore not be switched on in that case.
 so well tested.
   
 
-<br/><br/><strong>MultipartonInteractions:allowDoubleRescatter</strong>  <input type="radio" name="18" value="on"><strong>On</strong>
-<input type="radio" name="18" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>MultipartonInteractions:allowDoubleRescatter</strong>  <input type="radio" name="19" value="on"><strong>On</strong>
+<input type="radio" name="19" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Switch to allow rescattering of partons, where both incoming partons 
 have already rescattered; on/off = true/false. Is only used if 
@@ -314,13 +341,13 @@ shorthand for <code>MultipartonInteractions:ySepRescatter</code> and
 defined below. The description is symmetric between the two beams,
 so only one case is described below. 
 <br/>
-<input type="radio" name="19" value="0" checked="checked"><strong>0 </strong>: only scattered partons with <ei>y > 0</ei>  can collide with unscattered partons from beam B.<br/>
-<input type="radio" name="19" value="1"><strong>1 </strong>: only scattered partons with <ei>y > ySep</ei>  can collide with unscattered partons from beam B.<br/>
-<input type="radio" name="19" value="2"><strong>2 </strong>: the probability for a scattered parton to be considered  as a potential rescatterer against unscattered partons in beam B increases  linearly from zero at <ei>y = ySep - deltaY</ei> to unity at  <ei>y = ySep + deltaY</ei>.<br/>
-<input type="radio" name="19" value="3"><strong>3 </strong>: the probability for a scattered parton to be considered  as a potential rescatterer against unscattered partons in beam B increases  with <ei>y</ei> according to  <ei>(1/2) * (1 + tanh( (y - ySep) / deltaY))</ei>.<br/>
-<input type="radio" name="19" value="4"><strong>4 </strong>: all partons are potential rescatterers against both  beams.<br/>
+<input type="radio" name="20" value="0" checked="checked"><strong>0 </strong>: only scattered partons with <ei>y > 0</ei>  can collide with unscattered partons from beam B.<br/>
+<input type="radio" name="20" value="1"><strong>1 </strong>: only scattered partons with <ei>y > ySep</ei>  can collide with unscattered partons from beam B.<br/>
+<input type="radio" name="20" value="2"><strong>2 </strong>: the probability for a scattered parton to be considered  as a potential rescatterer against unscattered partons in beam B increases  linearly from zero at <ei>y = ySep - deltaY</ei> to unity at  <ei>y = ySep + deltaY</ei>.<br/>
+<input type="radio" name="20" value="3"><strong>3 </strong>: the probability for a scattered parton to be considered  as a potential rescatterer against unscattered partons in beam B increases  with <ei>y</ei> according to  <ei>(1/2) * (1 + tanh( (y - ySep) / deltaY))</ei>.<br/>
+<input type="radio" name="20" value="4"><strong>4 </strong>: all partons are potential rescatterers against both  beams.<br/>
 
-<br/><br/><table><tr><td><strong>MultipartonInteractions:ySepRescatter </td><td></td><td> <input type="text" name="20" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>MultipartonInteractions:ySepRescatter </td><td></td><td> <input type="text" name="21" value="0." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0.</strong></code>)</td></tr></table>
 used for some of the <code>MultipartonInteractions:rescatterMode</code>
 options above, as the rapidity for which a scattered parton has a 50%
 probability to be considered as a potential rescatterer. 
@@ -329,7 +356,7 @@ rescatter at all, while a <i>ySep < 0</i>  instead allows central
 partons to scatter against either beam.
    
 
-<br/><br/><table><tr><td><strong>MultipartonInteractions:deltaYRescatter </td><td></td><td> <input type="text" name="21" value="1." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>1.</strong></code>; <code>minimum = 0.1</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>MultipartonInteractions:deltaYRescatter </td><td></td><td> <input type="text" name="22" value="1." size="20"/>  &nbsp;&nbsp;(<code>default = <strong>1.</strong></code>; <code>minimum = 0.1</code>)</td></tr></table>
 used for some of the <code>MultipartonInteractions:rescatterMode</code>
 options above, as the width of the rapidity transition region, where the 
 probability rises from zero to unity that a scattered parton is considered 
@@ -342,13 +369,13 @@ as a potential rescatterer.
 These should normally not be touched. Their only function is for
 cross-checks.
 
-<br/><br/><table><tr><td><strong>MultipartonInteractions:nQuarkIn  </td><td></td><td> <input type="text" name="22" value="5" size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5</strong></code>; <code>minimum = 0</code>; <code>maximum = 5</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>MultipartonInteractions:nQuarkIn  </td><td></td><td> <input type="text" name="23" value="5" size="20"/>  &nbsp;&nbsp;(<code>default = <strong>5</strong></code>; <code>minimum = 0</code>; <code>maximum = 5</code>)</td></tr></table>
 Number of allowed incoming quark flavours in the beams; a change 
 to 4 would thus exclude <i>b</i> and <i>bbar</i> as incoming 
 partons, etc.
   
 
-<br/><br/><table><tr><td><strong>MultipartonInteractions:nSample  </td><td></td><td> <input type="text" name="23" value="1000" size="20"/>  &nbsp;&nbsp;(<code>default = <strong>1000</strong></code>; <code>minimum = 100</code>)</td></tr></table>
+<br/><br/><table><tr><td><strong>MultipartonInteractions:nSample  </td><td></td><td> <input type="text" name="24" value="1000" size="20"/>  &nbsp;&nbsp;(<code>default = <strong>1000</strong></code>; <code>minimum = 100</code>)</td></tr></table>
 The allowed <i>pT</i> range is split (unevenly) into 100 bins, 
 and in each of these the interaction cross section is evaluated in 
 <i>nSample</i> random phase space points. The full integral is used 
@@ -404,7 +431,7 @@ implies <i>sHat >> pT2</i> and thus a heavy parton-distribution
 penalty, while parton distributions are largest for 
 <i>tHat = uHat = -sHat/2</i>, where the above expression 
 evaluates to 5/9. A fudge factor is therefore introduced to go the 
-final step, so it can easily be modifed when further non-Rutherford 
+final step, so it can easily be modified when further non-Rutherford 
 processes are added, or should parton distributions change significantly.
 
 <p/>
@@ -478,7 +505,7 @@ time-consuming PDF+ME evaluation, with surviving events given a
 compensating weight <i>1/WT_y</i>. 
 
 <p/>
-An impact-parameter dependencs is also allowed. Based on the hard 
+An impact-parameter dependence is also allowed. Based on the hard 
 <i>pT</i> scale of the first interaction, and enhancement/depletion 
 factor is picked, which multiplies the rate of subsequent interactions.
 
@@ -582,39 +609,44 @@ if($_POST["16"] != "0.15")
 $data = "MultipartonInteractions:a1 = ".$_POST["16"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["17"] != "off")
+if($_POST["17"] != "1")
 {
-$data = "MultipartonInteractions:allowRescatter = ".$_POST["17"]."\n";
+$data = "MultipartonInteractions:bSelScale = ".$_POST["17"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["18"] != "off")
 {
-$data = "MultipartonInteractions:allowDoubleRescatter = ".$_POST["18"]."\n";
+$data = "MultipartonInteractions:allowRescatter = ".$_POST["18"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["19"] != "0")
+if($_POST["19"] != "off")
 {
-$data = "MultipartonInteractions:rescatterMode = ".$_POST["19"]."\n";
+$data = "MultipartonInteractions:allowDoubleRescatter = ".$_POST["19"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["20"] != "0.")
+if($_POST["20"] != "0")
 {
-$data = "MultipartonInteractions:ySepRescatter = ".$_POST["20"]."\n";
+$data = "MultipartonInteractions:rescatterMode = ".$_POST["20"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["21"] != "1.")
+if($_POST["21"] != "0.")
 {
-$data = "MultipartonInteractions:deltaYRescatter = ".$_POST["21"]."\n";
+$data = "MultipartonInteractions:ySepRescatter = ".$_POST["21"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["22"] != "5")
+if($_POST["22"] != "1.")
 {
-$data = "MultipartonInteractions:nQuarkIn = ".$_POST["22"]."\n";
+$data = "MultipartonInteractions:deltaYRescatter = ".$_POST["22"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["23"] != "1000")
+if($_POST["23"] != "5")
 {
-$data = "MultipartonInteractions:nSample = ".$_POST["23"]."\n";
+$data = "MultipartonInteractions:nQuarkIn = ".$_POST["23"]."\n";
+fwrite($handle,$data);
+}
+if($_POST["24"] != "1000")
+{
+$data = "MultipartonInteractions:nSample = ".$_POST["24"]."\n";
 fwrite($handle,$data);
 }
 fclose($handle);
@@ -624,4 +656,4 @@ fclose($handle);
 </body>
 </html>
 
-<!-- Copyright (C) 2012 Torbjorn Sjostrand -->
+<!-- Copyright (C) 2013 Torbjorn Sjostrand -->
