@@ -107,6 +107,8 @@ LHAPDF library[<a href="Bibliography.php" target="page">Wha05</a>].</li>
 MRST/MSTW group that have been implemented.</li>
 <li><code>CTEQ6pdf</code> gives the six distributions of the
 CTEQ/CT group that have been implemented.</li>
+<li><code>NNPDF</code> gives four distributions from the NNPDF 2.3
+QCD+QED sets that have been implemented.</li>
 </ul>
 The current default is CTEQ 5L, which has been used in most studies
 to date.
@@ -163,8 +165,8 @@ setup procedure of a PDF failed, e.g. if the user has chosen an unknown
 PDF set.  
 
 <p/> 
-The MRST/MSTW, CTEQ/CT and H1 PDF routines are based on the interpolation
-in <i>(x, Q)</i> grids. The grid files are stored in the 
+The MRST/MSTW, CTEQ/CT, NNPDF and H1 PDF routines are based on the 
+interpolation in <i>(x, Q)</i> grids. The grid files are stored in the 
 <code>xmldoc</code> subdirectory, like settings and particle data.
 Only PDF sets that will be used are read in during the initialization 
 stage.
