@@ -33,31 +33,33 @@ Here is collected processes involving supersymmetric particle
 production, with the exception of the (extended) Higgs sector.
 Since the number of separate but closely related processes is so big,
 there will not be switches for each separate process but only for a
-reasonable set of subgroups. However, the general 
-switches <code>SUSY:idA</code> and <code>SUSY:idB</code> may be used in
-conjunction with any of these groups to provide some additional
-flexibility to concentrate on processes involving only specific (s)particle
-final states, see below. 
+reasonable set of subgroups. However, the general switches 
+<code>SUSY:idA</code> and <code>SUSY:idB</code>,valternatively 
+vectors <code>SUSY:idVecA</code> and <code>SUSY:idVecB</code>,
+may be used in conjunction with any of these groups to provide 
+some additional flexibility to concentrate on processes involving 
+only specific (s)particle final states, see below. 
 </p>
 
 <p>
 Most of the SUSY implementation in PYTHIA 8 has been written by
-N. Desai, in combination with an MCnet studentship at CERN in
-2010, with further work having been carried out during 2011. 
-The implementation is documented in [<a href="Bibliography.php" target="page">Des11</a>]. Please give due
+N. Desai and is documented in [<a href="Bibliography.php" target="page">Des11</a>]. Please give due
 credit to external contributions to PYTHIA 8, such as this one, by
 including the original work in your list of references when using this
-implementation. 
+implementation. The cross section formulae are mostly taken from 
+[<a href="Bibliography.php" target="page">Boz07</a>] and [<a href="Bibliography.php" target="page">Fuk11</a>].
 </p>
 
 <p>Since the implementation of SUSY processes was only recently
 completed [<a href="Bibliography.php" target="page">Des11</a>], case-by-case validations against other codes 
-are still recommended. In all cases, a set of default validations have 
-already been carried out by the authors. These validations compared to 
-the PYTHIA 6 SUSY implementation, using an sps1a spectrum. Most of the
-SLHA2-specific extensions have  not been explicitly validated,
-however, with the exception of the R-parity violating single-sparticle
-production cross sections.
+are still recommended. A set of default validations have 
+already been carried out by the authors, comparing to 
+the PYTHIA 6 SUSY implementation and to the XSUSY code, 
+using an sps1a spectrum. Explicit
+validations of the non-trivial SLHA2-specific extensions have
+generally not been carried out yet, with the exception of the R-parity
+violating single-sparticle production cross sections. Please report
+the results of any user validations you may carry out to the authors. 
 </p>
 
 <br/><b>Important Note on SLHA:</b> 
@@ -87,10 +89,7 @@ echo "<a href='RHadrons.php?filepath=".$filepath."' target='page'>";?>the R-hadr
 
 <br/><b>Note 3:</b> lepton- and photon-initial states are not yet available. 
 Only quark/gluon-initiated <i>2 -> 2</i> and <i>2 -> 1</i> (RPV) 
-processes have been implemented. Likewise, direct slepton production 
-has not yet been implemented (i.e., <i>2 -> 2</i> processes
-involving sleptons in the final state). Sleptons will of course still be
-produced through cascade decays of heavier (s)particles. 
+processes have been implemented. 
 
 <br/><b>Note 4:</b> cross sections will be correctly folded with open
 branching fractions of cascade decays, but at present any difference between
@@ -110,9 +109,9 @@ Option to limit the sum over possible outgoing states in SUSY
 identity code. The default corresponds to summing over all possible 
 indices. A non-zero value of <code>SUSY:idA</code> selects only processes 
 that contain the state corresponding to that particular particle identity 
-code in the fundamental <i>2 -> 2</i> scattering process (symmetrized 
+code in the fundamental <i>2 -> 2</i> scattering process (summed
 over particle/antiparticle). It is the user's responsibility to ensure 
-that (a subset of) the processes be to simulated actually include this 
+that (a subset of) the processes to be simulated actually include this 
 particle at the <i>2 -> 2</i> level; thus, asking for the lightest 
 neutralino (code 1000021) to be present in a squark-squark production 
 process will give no match. 
@@ -124,59 +123,87 @@ with PDG code <code>SUSY:idB</code> to be present in the <i>2 -> 2</i>
 process. Thus, using  <code>SUSY:idA</code> and  <code>SUSY:idB</code> 
 a specific subprocess can be selected. Again only the absolute sign is 
 used, i.e. the summation over particle and antiparticle is retained.
+Also the order of <code>SUSY:idA</code> and <code>SUSY:idB</code> is
+irrelevant; since both possible orderings are checked for a match 
+with the two outgoing particles. (Although not recommended, should 
+<code>SUSY:idA</code> be zero and <code>SUSY:idB</code> nonzero
+a match is searched for just like in the normal case with 
+<code>SUSY:idA</code> nonzero and <code>SUSY:idB</code> zero.)  
+  
+
+<br/><br/><table><tr><td><strong>SUSY:idVecA  </td><td></td><td> <input type="text" name="4" value="0" size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0</strong></code>; <code>minimum = 0</code>)</td></tr></table>
+As for <code>SUSY:idA</code>, but as a vector of PDG codes. 
+(Character-string input of such vectors should be as a 
+comma-separated list, without any blanks.) Thus, it selects only 
+processes that have a final-state particle corresponding to one 
+of the identity codes in this vector. Note that, to activate this, 
+<code>SUSY:idA</code> must be equal to zero; if not then the match 
+to <code>SUSY:idA</code> takes precedence. 
+  
+
+<br/><br/><table><tr><td><strong>SUSY:idVecB  </td><td></td><td> <input type="text" name="5" value="0" size="20"/>  &nbsp;&nbsp;(<code>default = <strong>0</strong></code>; <code>minimum = 0</code>)</td></tr></table>
+As for <code>SUSY:idB</code>, but as a vector of PDG codes. 
+(Character-string input of such vectors should be as a 
+comma-separated list, without any blanks.) As above, to activate this, 
+<code>SUSY:idB</code> must be equal to zero; if not then the match to 
+<code>SUSY:idB</code> takes precedence. For the matching, either of 
+<code>SUSY:idA</code> and <code>SUSY:idVecA</code> may be combined with 
+either of <code>SUSY:idB</code> and <code>SUSY:idVecB</code>.
+As above one of the two outgoing SUSY particles must match one of the
+particles in <code>SUSY:id(Vec)A</code> and the other one of the 
+particles in <code>SUSY:id(Vec)B</code> when both are nonzero.
   
 
 <br/><br/><table><tr><td><strong>SUSY:sin2thetaWMode  </td><td>  &nbsp;&nbsp;(<code>default = <strong>2</strong></code>; <code>minimum = 1</code>; <code>maximum = 3</code>)</td></tr></table>
 The value of <ei>sin2(thetaW)</ei> should be taken from
 <br/>
-<input type="radio" name="4" value="1"><strong>1 </strong>: SM value, defined at <ei>M_Z</ei>, taken from PYTHIA's <code>StandardModel:sin2thetaW</code> parameter.<br/>
-<input type="radio" name="4" value="2" checked="checked"><strong>2 </strong>: SUSY value, defined at <ei>M_SUSY</ei>, derived from the running gauge couplings in <code>BLOCK GAUGE</code> in the SLHA file. Note: if no such block is present in the input file, this option will default back to option 1 above, i.e., the SM value.<br/>
-<input type="radio" name="4" value="3"><strong>3 </strong>: Pole value, defined by <ei>1 - M_W^2/M_Z^2</ei>,  using the pole masses stored in the SLHA <code>BLOCK MASS</code>, or,  alternatively, PYTHIA's internal pole masses if no such block is  present.<br/>
+<input type="radio" name="6" value="1"><strong>1 </strong>: SM value, defined at <ei>M_Z</ei>, taken from PYTHIA's <code>StandardModel:sin2thetaW</code> parameter.<br/>
+<input type="radio" name="6" value="2" checked="checked"><strong>2 </strong>: SUSY value, defined at <ei>M_SUSY</ei>, derived from the running gauge couplings in <code>BLOCK GAUGE</code> in the SLHA file. Note: if no such block is present in the input file, this option will default back to option 1 above, i.e., the SM value.<br/>
+<input type="radio" name="6" value="3"><strong>3 </strong>: Pole value, defined by <ei>1 - M_W^2/M_Z^2</ei>,  using the pole masses stored in the SLHA <code>BLOCK MASS</code>, or,  alternatively, PYTHIA's internal pole masses if no such block is  present.<br/>
 
 <h4>Gluino Pair Production</h4>
 
-<br/><br/><strong>SUSY:gg2gluinogluino</strong>  <input type="radio" name="5" value="on"><strong>On</strong>
-<input type="radio" name="5" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:gg2gluinogluino</strong>  <input type="radio" name="7" value="on"><strong>On</strong>
+<input type="radio" name="7" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Pair production of gluinos by gluon-gluon initial states. 
   
 
-<br/><br/><strong>SUSY:qqbar2gluinogluino</strong>  <input type="radio" name="6" value="on"><strong>On</strong>
-<input type="radio" name="6" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qqbar2gluinogluino</strong>  <input type="radio" name="8" value="on"><strong>On</strong>
+<input type="radio" name="8" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Pair production of gluinos by quark-antiquark annihilation and
-<i>t</i>-channel squark exchange. So far, these cross sections assume the
-squark CKM is aligned with the quark CKM and that all quantities are
-real, so effects of non-minimal flavour violation and/or CP violation
-are not yet included.
+<i>t</i>-channel squark exchange.  The cross section
+expression follows [<a href="Bibliography.php" target="page">Fuk11</a>] and include the possibility 
+of non-minimal flavour violation through misalignment of quarks with
+squarks. Only the MFV case has been explicitly validated. 
   
 
 <h4>Associated Squark-Gluino Production</h4>
 
-<br/><br/><strong>SUSY:qg2squarkgluino</strong>  <input type="radio" name="7" value="on"><strong>On</strong>
-<input type="radio" name="7" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qg2squarkgluino</strong>  <input type="radio" name="9" value="on"><strong>On</strong>
+<input type="radio" name="9" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
-Associated production of a squark with a gluino. Only implemented for the
-flavor-diagonal case. So far, these cross sections assume the
-squark CKM is aligned with the quark CKM and that all quantities are
-real, so effects of non-minimal flavour violation and/or CP violation
-are not yet included.
+Associated production of a squark with a gluino. The cross section
+expression follows [<a href="Bibliography.php" target="page">Fuk11</a>] and include the possibility 
+of non-minimal flavour violation through misalignment of quarks with
+squarks. Only the MFV case has been explicitly validated. 
   
 
 <h4>Squark Pair Production</h4>
 
-<br/><br/><strong>SUSY:gg2squarkantisquark</strong>  <input type="radio" name="8" value="on"><strong>On</strong>
-<input type="radio" name="8" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:gg2squarkantisquark</strong>  <input type="radio" name="10" value="on"><strong>On</strong>
+<input type="radio" name="10" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Pair production of a scalar quark together with a scalar antiquark by
 gluon annihilation via <i>s</i>-channel gluon exchange, <i>t</i>- and 
 <i>u</i>-channel squark exchange, and the direct 4-point coupling. 
 The cross section expression follows [<a href="Bibliography.php" target="page">Boz07</a>]. 
-Validation of the FLV and CPV cases has not yet been completed.
+Only the MFV case has been explicitly validated. 
   
 
-<br/><br/><strong>SUSY:qqbar2squarkantisquark</strong>  <input type="radio" name="9" value="on"><strong>On</strong>
-<input type="radio" name="9" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qqbar2squarkantisquark</strong>  <input type="radio" name="11" value="on"><strong>On</strong>
+<input type="radio" name="11" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Pair production of a scalar quark together with a scalar antiquark 
 by quark-antiquark annihilation. 
@@ -189,15 +216,15 @@ are neglected). For opposite-isospin <i>~q~q*</i> production
 and <i>t</i>-channel gluino contributions have been implemented 
 (i.e., the <i>t</i>-channel neutralino contributions are neglected). 
 The cross section expressions follow [<a href="Bibliography.php" target="page">Boz07</a>]. 
-Validation of the FLV and CPV cases has not yet been completed.
+Only the MFV case has been explicitly validated. 
 (Note to PYTHIA 6 users: 
 in older PYTHIA 6 versions, a bug caused the <i>~t1~t2*</i> cross to be
 overcounted by a factor of 2. Starting from version 6.4.24, that
 generator now agrees with the implementation here.)
   
 
-<br/><br/><strong>SUSY:qqbar2squarkantisquark:onlyQCD</strong>  <input type="radio" name="10" value="on"><strong>On</strong>
-<input type="radio" name="10" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qqbar2squarkantisquark:onlyQCD</strong>  <input type="radio" name="12" value="on"><strong>On</strong>
+<input type="radio" name="12" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 When switched <code>on</code> this flag switches off all but the 
 <i>s</i>-channel gluon contribution in the
@@ -207,14 +234,14 @@ accurate physics simulation, leave this flag in the <code>off</code>
 position.  
   
 
-<br/><br/><strong>SUSY:qq2squarksquark</strong>  <input type="radio" name="11" value="on"><strong>On</strong>
-<input type="radio" name="11" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qq2squarksquark</strong>  <input type="radio" name="13" value="on"><strong>On</strong>
+<input type="radio" name="13" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Pair production of scalar quarks (squark-squark and its charge
 conjugate process; for squark-antisquark production see above) 
 by <i>t</i>- and <i>u</i>-channel gluino, neutralino, and 
 chargino exchange. The cross section expressions follow [<a href="Bibliography.php" target="page">Boz07</a>]. 
-Validation of the FLV and CPV cases has not yet been completed.
+Only the MFV case has been explicitly validated. 
 (Note to PYTHIA 6 users: PYTHIA 6 only included the gluino exchange
 contribution, which typically dominates due to the size of the strong
 coupling; for counterchecks, 
@@ -223,8 +250,8 @@ below can be switched on to eliminate the chargino and neutralino
 contributions.)
   
 
-<br/><br/><strong>SUSY:qq2squarksquark:onlyQCD</strong>  <input type="radio" name="12" value="on"><strong>On</strong>
-<input type="radio" name="12" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qq2squarksquark:onlyQCD</strong>  <input type="radio" name="14" value="on"><strong>On</strong>
+<input type="radio" name="14" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 When switched <code>on</code> this flag causes the <i>t</i>- or 
 <i>u</i>-channel neutralino and chargino contributions to be 
@@ -235,78 +262,91 @@ leave this flag in the <code>off</code> position.
 
 <h4>Neutralino and Chargino Pair Production</h4>
 
-<br/><br/><strong>SUSY:qqbar2chi0chi0</strong>  <input type="radio" name="13" value="on"><strong>On</strong>
-<input type="radio" name="13" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qqbar2chi0chi0</strong>  <input type="radio" name="15" value="on"><strong>On</strong>
+<input type="radio" name="15" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Pair production of neutralinos by quark-antiquark annihilation. With
 four neutralino species this gives ten separate processes, codes 
 1201 - 1210. The cross section expressions follow [<a href="Bibliography.php" target="page">Boz07</a>].
-Validation of the FLV and CPV cases has not yet been completed.
+Only the MFV case has been explicitly validated. 
   
 
-<br/><br/><strong>SUSY:qqbar2chi+-chi0</strong>  <input type="radio" name="14" value="on"><strong>On</strong>
-<input type="radio" name="14" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qqbar2chi+-chi0</strong>  <input type="radio" name="16" value="on"><strong>On</strong>
+<input type="radio" name="16" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Associated chargino-neutralino production by quark-antiquark
 annihilation. With four neutralino species, two chargino ones, and
 maintaining charge conjugate processes separate, this gives 16 
 separate processes, codes 1221 - 1236. The cross section expressions 
 follow [<a href="Bibliography.php" target="page">Boz07</a>].
-Validation of the FLV and CPV cases has not yet been completed.
+Only the MFV case has been explicitly validated. 
   
 
-<br/><br/><strong>SUSY:qqbar2chi+chi-</strong>  <input type="radio" name="15" value="on"><strong>On</strong>
-<input type="radio" name="15" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qqbar2chi+chi-</strong>  <input type="radio" name="17" value="on"><strong>On</strong>
+<input type="radio" name="17" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Pair production of charginos by quark-antiquark annihilation. With
 two chargino species and maintaining mutually charge conjugate
 processes separate, this gives four separate processes, codes 
 1241 - 1244. The cross section expressions follow [<a href="Bibliography.php" target="page">Boz07</a>]. 
-Validation of the FLV and CPV cases has not yet been completed.
+Only the MFV case has been explicitly validated. 
   
 
 <h4>Associated Neutralino/Chargino + Squark/Gluino Production</h4>
 
-<br/><br/><strong>SUSY:qg2chi0squark</strong>  <input type="radio" name="16" value="on"><strong>On</strong>
-<input type="radio" name="16" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qg2chi0squark</strong>  <input type="radio" name="18" value="on"><strong>On</strong>
+<input type="radio" name="18" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Pair production of neutralinos from quark-gluon initial states.
 The cross section expressions follow [<a href="Bibliography.php" target="page">Boz07</a>].
-Validation of the FLV and CPV cases has not yet been completed.
+Only the MFV case has been explicitly validated. 
   
 
-<br/><br/><strong>SUSY:qg2chi+-squark</strong>  <input type="radio" name="17" value="on"><strong>On</strong>
-<input type="radio" name="17" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qg2chi+-squark</strong>  <input type="radio" name="19" value="on"><strong>On</strong>
+<input type="radio" name="19" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Associated chargino-squark production from quark-gluon initial states.
 annihilation. The cross section expressions
 follow [<a href="Bibliography.php" target="page">Boz07</a>].
-Validation of the FLV and CPV cases has not yet been completed.
+Only the MFV case has been explicitly validated. 
   
 
-<br/><br/><strong>SUSY:qqbar2chi0gluino</strong>  <input type="radio" name="18" value="on"><strong>On</strong>
-<input type="radio" name="18" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qqbar2chi0gluino</strong>  <input type="radio" name="20" value="on"><strong>On</strong>
+<input type="radio" name="20" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Associated neutralino-gluino production by quark-antiquark
-annihilation. Status: not implemented yet.
+annihilation. 
+The cross section expressions follow 
+[<a href="Bibliography.php" target="page">Fuk11</a>]. Only the MFV case has been explicitly validated.  
   
 
-<br/><br/><strong>SUSY:qqbar2chi+-gluino</strong>  <input type="radio" name="19" value="on"><strong>On</strong>
-<input type="radio" name="19" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qqbar2chi+-gluino</strong>  <input type="radio" name="21" value="on"><strong>On</strong>
+<input type="radio" name="21" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Associated chargino-gluino production by quark-antiquark
-annihilation. Status: not implemented yet.
+annihilation. The cross section expressions follow 
+[<a href="Bibliography.php" target="page">Fuk11</a>]. Only the MFV case has been explicitly
+validated. (Note to PYTHIA 6 users: small differences between
+this implementation and PYTHIA 6 arise due 
+to slightly different treatments of the weak mixing angle, 
+which is fixed in PYTHIA 6, while it is computed from the SLHA input
+in PYTHIA 8; see <code>SUSY:sin2thetaWMode</code> above.)
   
 
 <h4>Slepton Production</h4>
+<br/><br/><strong>SUSY:qqbar2sleptonantislepton</strong>  <input type="radio" name="22" value="on"><strong>On</strong>
+<input type="radio" name="22" value="off" checked="checked"><strong>Off</strong>
+ &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
+Pair production of slepton-antislepton via s-channel W, Z and gamma
+exchange.  Includes both charged sleptons and sneutrinos but right
+handed sneutrinos currently not supported.
+  
 
-No 2->2 slepton pair production or associated slepton production 
-cross sections have been implemented yet. 
 
 <h4>R-parity violating squark production</h4>
 
-<br/><br/><strong>SUSY:qq2antisquark</strong>  <input type="radio" name="20" value="on"><strong>On</strong>
-<input type="radio" name="20" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSY:qq2antisquark</strong>  <input type="radio" name="23" value="on"><strong>On</strong>
+<input type="radio" name="23" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Resonant squark production via R-parity violating UDD couplings. The
 couplings must be input using the SLHA2 structure. 
@@ -342,11 +382,11 @@ are: 3-body decays of charginos (via RPV), and 2-body decays of squarks and
 gauginos with Higgs as one of the decay products. 
 
 Some 3-body decays have been implemented with Matrix Element weighting.  
-In particular, those for a neutralino to a lighter neutralino and a fermion pair 
-can be enabled.
+In particular, those for a neutralino to a lighter neutralino and a
+fermion pair can be enabled.
 
-<br/><br/><strong>SUSYResonance:3BodyMatrixElement</strong>  <input type="radio" name="21" value="on"><strong>On</strong>
-<input type="radio" name="21" value="off" checked="checked"><strong>Off</strong>
+<br/><br/><strong>SUSYResonance:3BodyMatrixElement</strong>  <input type="radio" name="24" value="on"><strong>On</strong>
+<input type="radio" name="24" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 When "on", the spin-averaged, squared matrix element is used
 to sample the phase space for resonance decay.  Currently, only
@@ -385,94 +425,109 @@ if($_POST["3"] != "0")
 $data = "SUSY:idB = ".$_POST["3"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["4"] != "2")
+if($_POST["4"] != "0")
 {
-$data = "SUSY:sin2thetaWMode = ".$_POST["4"]."\n";
+$data = "SUSY:idVecA = ".$_POST["4"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["5"] != "off")
+if($_POST["5"] != "0")
 {
-$data = "SUSY:gg2gluinogluino = ".$_POST["5"]."\n";
+$data = "SUSY:idVecB = ".$_POST["5"]."\n";
 fwrite($handle,$data);
 }
-if($_POST["6"] != "off")
+if($_POST["6"] != "2")
 {
-$data = "SUSY:qqbar2gluinogluino = ".$_POST["6"]."\n";
+$data = "SUSY:sin2thetaWMode = ".$_POST["6"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["7"] != "off")
 {
-$data = "SUSY:qg2squarkgluino = ".$_POST["7"]."\n";
+$data = "SUSY:gg2gluinogluino = ".$_POST["7"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["8"] != "off")
 {
-$data = "SUSY:gg2squarkantisquark = ".$_POST["8"]."\n";
+$data = "SUSY:qqbar2gluinogluino = ".$_POST["8"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["9"] != "off")
 {
-$data = "SUSY:qqbar2squarkantisquark = ".$_POST["9"]."\n";
+$data = "SUSY:qg2squarkgluino = ".$_POST["9"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["10"] != "off")
 {
-$data = "SUSY:qqbar2squarkantisquark:onlyQCD = ".$_POST["10"]."\n";
+$data = "SUSY:gg2squarkantisquark = ".$_POST["10"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["11"] != "off")
 {
-$data = "SUSY:qq2squarksquark = ".$_POST["11"]."\n";
+$data = "SUSY:qqbar2squarkantisquark = ".$_POST["11"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["12"] != "off")
 {
-$data = "SUSY:qq2squarksquark:onlyQCD = ".$_POST["12"]."\n";
+$data = "SUSY:qqbar2squarkantisquark:onlyQCD = ".$_POST["12"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["13"] != "off")
 {
-$data = "SUSY:qqbar2chi0chi0 = ".$_POST["13"]."\n";
+$data = "SUSY:qq2squarksquark = ".$_POST["13"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["14"] != "off")
 {
-$data = "SUSY:qqbar2chi+-chi0 = ".$_POST["14"]."\n";
+$data = "SUSY:qq2squarksquark:onlyQCD = ".$_POST["14"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["15"] != "off")
 {
-$data = "SUSY:qqbar2chi+chi- = ".$_POST["15"]."\n";
+$data = "SUSY:qqbar2chi0chi0 = ".$_POST["15"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["16"] != "off")
 {
-$data = "SUSY:qg2chi0squark = ".$_POST["16"]."\n";
+$data = "SUSY:qqbar2chi+-chi0 = ".$_POST["16"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["17"] != "off")
 {
-$data = "SUSY:qg2chi+-squark = ".$_POST["17"]."\n";
+$data = "SUSY:qqbar2chi+chi- = ".$_POST["17"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["18"] != "off")
 {
-$data = "SUSY:qqbar2chi0gluino = ".$_POST["18"]."\n";
+$data = "SUSY:qg2chi0squark = ".$_POST["18"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["19"] != "off")
 {
-$data = "SUSY:qqbar2chi+-gluino = ".$_POST["19"]."\n";
+$data = "SUSY:qg2chi+-squark = ".$_POST["19"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["20"] != "off")
 {
-$data = "SUSY:qq2antisquark = ".$_POST["20"]."\n";
+$data = "SUSY:qqbar2chi0gluino = ".$_POST["20"]."\n";
 fwrite($handle,$data);
 }
 if($_POST["21"] != "off")
 {
-$data = "SUSYResonance:3BodyMatrixElement = ".$_POST["21"]."\n";
+$data = "SUSY:qqbar2chi+-gluino = ".$_POST["21"]."\n";
+fwrite($handle,$data);
+}
+if($_POST["22"] != "off")
+{
+$data = "SUSY:qqbar2sleptonantislepton = ".$_POST["22"]."\n";
+fwrite($handle,$data);
+}
+if($_POST["23"] != "off")
+{
+$data = "SUSY:qq2antisquark = ".$_POST["23"]."\n";
+fwrite($handle,$data);
+}
+if($_POST["24"] != "off")
+{
+$data = "SUSYResonance:3BodyMatrixElement = ".$_POST["24"]."\n";
 fwrite($handle,$data);
 }
 fclose($handle);
